@@ -257,6 +257,7 @@
 \\pushToTag
 \\pt
 \\propertyUnset
+\\propertyTweak
 \\propertySet
 \\propertyRevert
 \\propertyOverride
@@ -402,6 +403,7 @@
 \\medium
 \\maxima
 \\markuplist
+\\markupMap
 \\markup
 \\markletter
 \\markalphabet
