@@ -249,12 +249,17 @@ used.  This is used to select the proper design size for the text fonts.
 ; "emmentaler", "sans-serif", and "monospace", respectively. All fonts are
 ; still accesible through the usual scheme symbols: 'feta, 'roman, 'sans, and
 ; 'typewriter.
+;
+; Note that 'LilyPond Serif', 'LilyPond Sans Serif' and 'Lilypond Monospace'
+; are aliases that are defined in mf/00-lilypond-fonts.conf.in (source file)
+; or fonts/00-lilypond-fonts.conf (installed file).
+
 (define*-public (set-global-fonts #:key 
   (music "emmentaler")
   (brace "emmentaler")
-  (roman "Century Schoolbook L")
-  (sans "sans-serif")
-  (typewriter "monospace")
+  (roman "LilyPond Serif")
+  (sans "LilyPond Sans Serif")
+  (typewriter "LilyPond Monospace")
   (factor 1))
   (let ((n (make-font-tree-node 'font-encoding 'fetaMusic)))
     (add-music-fonts n 'feta music brace feta-design-size-mapping factor)
@@ -273,9 +278,9 @@ used.  This is used to select the proper design size for the text fonts.
 
 (define-public (make-century-schoolbook-tree factor)
   (make-pango-font-tree
-   "Century Schoolbook L"
-   "sans-serif"
-   "monospace"
+   "LilyPond Serif"
+   "LilyPond Sans Serif"
+   "LilyPond Monospace"
    factor))
 
 (define-public all-text-font-encodings
